pub struct SessionRef {
pub path: PathBuf,
pub agent: String,
pub project: Option<String>,
pub size_bytes: u64,
pub modified: Option<Timestamp>,
}Expand description
Lightweight pointer to one session file on disk, produced by Adapter::discover.
Fields
path: PathBufagent: StringAdapter id, e.g. "claude-code".
project: Option<String>Project label as the agent records it (for Claude Code: the URL-encoded
cwd directory name, e.g. F--skiagram).
size_bytes: u64modified: Option<Timestamp>Trait Implementations
Sourceimpl Clone for SessionRef
impl Clone for SessionRef
Sourcefn clone(&self) -> SessionRef
fn clone(&self) -> SessionRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionRef
impl Debug for SessionRef
Sourceimpl<'de> Deserialize<'de> for SessionRef
impl<'de> Deserialize<'de> for SessionRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SessionRef
impl PartialEq for SessionRef
Sourcefn eq(&self, other: &SessionRef) -> bool
fn eq(&self, other: &SessionRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SessionRef
impl Serialize for SessionRef
impl StructuralPartialEq for SessionRef